@@ -192,6 +192,11 @@ class HiveServer2Cursor(Cursor):
         # PEP 249
         return self._rowcount
 
+    @property
+    def lastrowid(self):
+        # PEP 249
+        return None
+
     @property
     def query_string(self):
         return self._last_operation_string
@@ -337,7 +342,7 @@ class HiveServer2Cursor(Cursor):
 
             op = self.session.execute(self._last_operation_string,
                                       configuration,
-                                      async=True)
+                                      run_async=True)
             self._last_operation = op
 
         self._execute_async(op)
@@ -685,6 +690,7 @@ _TTypeId_to_TColumnValue_getters = {
     'ARRAY': operator.attrgetter('stringVal'),
     'STRUCT': operator.attrgetter('stringVal'),
     'UNIONTYPE': operator.attrgetter('stringVal'),
+    'NULL': operator.attrgetter('stringVal'),
     'DATE': operator.attrgetter('stringVal')
 }
 
@@ -1019,11 +1025,11 @@ class HS2Session(ThriftRPC):
         req = TCloseSessionReq(sessionHandle=self.handle)
         self._rpc('CloseSession', req)
 
-    def execute(self, statement, configuration=None, async=False):
+    def execute(self, statement, configuration=None, run_async=False):
         req = TExecuteStatementReq(sessionHandle=self.handle,
                                    statement=statement,
                                    confOverlay=configuration,
-                                   runAsync=async)
+                                   runAsync=run_async)
         return self._operation('ExecuteStatement', req)
 
     def get_databases(self, schema='.*'):
