@@ -19,7 +19,7 @@ from __future__ import absolute_import
 import re
 
 from sqlalchemy.dialects import registry
-from sqlalchemy.engine.default import DefaultDialect
+from sqlalchemy.engine.default import DefaultDialect, DefaultExecutionContext
 from sqlalchemy.sql.compiler import IdentifierPreparer, GenericTypeCompiler
 from sqlalchemy.types import (BOOLEAN, SMALLINT, BIGINT, TIMESTAMP, FLOAT,
                               DECIMAL, Integer, Float, String)
@@ -108,6 +108,12 @@ _impala_type_to_sqlalchemy_type = {
     'STRING': STRING,
     'DECIMAL': DECIMAL}
 
+class ImpalaExecutionContext(DefaultExecutionContext):
+       def create_cursor(self):
+           self._is_server_side = False
+           cursor_configuration = self.execution_options.get('cursor_configuration', {})
+           return self._dbapi_connection.cursor(configuration=cursor_configuration)
+
 
 class ImpalaDialect(DefaultDialect):
     name = 'impala'
@@ -124,6 +130,7 @@ class ImpalaDialect(DefaultDialect):
     supports_default_values = False
     returns_unicode_strings = True
     type_compiler = ImpalaTypeCompiler
+    execution_ctx_cls = ImpalaExecutionContext
 
     @classmethod
     def dbapi(cls):
@@ -152,6 +159,10 @@ class ImpalaDialect(DefaultDialect):
             query += ' IN %s' % schema
         return [tup[0] for tup in connection.execute(query).fetchall()]
 
+    def get_schema_names(self, connection, **kw):
+        rp = connection.execute("SHOW SCHEMAS")
+        return [r[0] for r in rp]
+
     def get_columns(self, connection, table_name, schema=None, **kwargs):
         # pylint: disable=unused-argument
         name = table_name
